EXPORTS
	??0CTestStep@@QAE@ABVTDesC16@@@Z @ 1 NONAME ; public: __thiscall CTestStep::CTestStep(class TDesC16 const &)
	??0CTestStep@@QAE@XZ @ 2 NONAME ; public: __thiscall CTestStep::CTestStep(void)
	??1CLog@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CLog::~CLog(void)
	??1CTestStep@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CTestStep::~CTestStep(void)
	??1CTestSuite@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CTestSuite::~CTestSuite(void)
	?AddTestStepL@CTestSuite@@QAEXPAVCTestStep@@@Z @ 6 NONAME ; public: void __thiscall CTestSuite::AddTestStepL(class CTestStep *)
	?CloseLog@CFileLogger@@QAEXXZ @ 7 NONAME ; public: void __thiscall CFileLogger::CloseLog(void)
	?CloseLogFile@CLog@@QAEXXZ @ 8 NONAME ; public: void __thiscall CLog::CloseLogFile(void)
	?Connect@CFileLogger@@QAEHXZ @ 9 NONAME ; public: int __thiscall CFileLogger::Connect(void)
	?Construct@CLog@@QAEXPAVCConsoleBase@@@Z @ 10 NONAME ; public: void __thiscall CLog::Construct(class CConsoleBase *)
	?ConstructL@CTestSuite@@QAEXXZ @ 11 NONAME ; public: void __thiscall CTestSuite::ConstructL(void)
	?CreateLog@CFileLogger@@QAEXABVTDesC16@@0@Z @ 12 NONAME ; public: void __thiscall CFileLogger::CreateLog(class TDesC16 const &,class TDesC16 const &)
	?DoTestStep@CTestSuite@@QAE?AW4TVerdict@@AAVTDesC16@@0@Z @ 13 NONAME ; public: enum TVerdict  __thiscall CTestSuite::DoTestStep(class TDesC16 &,class TDesC16 &)
	?DoTestUnit@CTestSuite@@UAE?AW4TVerdict@@AAVTDesC16@@@Z @ 14 NONAME ; public: virtual enum TVerdict  __thiscall CTestSuite::DoTestUnit(class TDesC16 &)
	?EpocErrorToText@CLog@@SA?AVTPtrC16@@H@Z @ 15 NONAME ; public: static class TPtrC16  __cdecl CLog::EpocErrorToText(int)
	?EpocErrorToText@CTestStep@@IAE?AVTPtrC16@@H@Z @ 16 NONAME ; protected: class TPtrC16  __thiscall CTestStep::EpocErrorToText(int)
	?GetBoolFromConfig@CTestStep@@IAEHABVTDesC16@@0AAH@Z @ 17 NONAME ; protected: int __thiscall CTestStep::GetBoolFromConfig(class TDesC16 const &,class TDesC16 const &,int &)
	?GetIntFromConfig@CTestStep@@IAEHABVTDesC16@@0AAH@Z @ 18 NONAME ; protected: int __thiscall CTestStep::GetIntFromConfig(class TDesC16 const &,class TDesC16 const &,int &)
	?GetStringFromConfig@CTestStep@@IAEHABVTDesC16@@0AAVTPtrC16@@@Z @ 19 NONAME ; protected: int __thiscall CTestStep::GetStringFromConfig(class TDesC16 const &,class TDesC16 const &,class TPtrC16 &)
	?GetVersion@CTestSuite@@UAE?AVTPtrC16@@XZ @ 20 NONAME ; public: virtual class TPtrC16  __thiscall CTestSuite::GetVersion(void)
	?LoadConfig@CTestStep@@QAEXAAVTDesC16@@@Z @ 21 NONAME ; public: void __thiscall CTestStep::LoadConfig(class TDesC16 &)
	?Log@CLog@@QAAXHV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 22 NONAME ; public: void __cdecl CLog::Log(int,class TRefByValue<class TDesC16 const >,...)
	?Log@CLog@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 23 NONAME ; public: void __cdecl CLog::Log(class TRefByValue<class TDesC16 const >,...)
	?Log@CLog@@QAEXV?$TRefByValue@$$CBVTDesC16@@@@QAPAC@Z @ 24 NONAME ; public: void __thiscall CLog::Log(class TRefByValue<class TDesC16 const >,signed char * * const)
	?Log@CTestStep@@IAAXHV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 25 NONAME ; protected: void __cdecl CTestStep::Log(int,class TRefByValue<class TDesC16 const >,...)
	?Log@CTestStep@@IAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 26 NONAME ; protected: void __cdecl CTestStep::Log(class TRefByValue<class TDesC16 const >,...)
	?Log@CTestSuite@@QAAXHV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 27 NONAME ; public: void __cdecl CTestSuite::Log(int,class TRefByValue<class TDesC16 const >,...)
	?Log@CTestSuite@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 28 NONAME ; public: void __cdecl CTestSuite::Log(class TRefByValue<class TDesC16 const >,...)
	?LogBlankLine@CLog@@QAEXH@Z @ 29 NONAME ; public: void __thiscall CLog::LogBlankLine(int)
	?LogExtra@CLog@@QAAXPBEHHV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 30 NONAME ; public: void __cdecl CLog::LogExtra(unsigned char const *,int,int,class TRefByValue<class TDesC16 const >,...)
	?LogExtra@CLog@@QAEXPBEHHV?$TRefByValue@$$CBVTDesC16@@@@QAPAC@Z @ 31 NONAME ; public: void __thiscall CLog::LogExtra(unsigned char const *,int,int,class TRefByValue<class TDesC16 const >,signed char * * const)
	?LogExtra@CTestStep@@IAAXPBEHHV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 32 NONAME ; protected: void __cdecl CTestStep::LogExtra(unsigned char const *,int,int,class TRefByValue<class TDesC16 const >,...)
	?LogExtra@CTestSuite@@QAAXPBEHHV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 33 NONAME ; public: void __cdecl CTestSuite::LogExtra(unsigned char const *,int,int,class TRefByValue<class TDesC16 const >,...)
	?LogResult@CLog@@QAAXW4TVerdict@@V?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 34 NONAME ; public: void __cdecl CLog::LogResult(enum TVerdict,class TRefByValue<class TDesC16 const >,...)
	?NewL@CLog@@SAPAV1@PAVCConsoleBase@@@Z @ 35 NONAME ; public: static class CLog * __cdecl CLog::NewL(class CConsoleBase *)
	?NewL@CTestUtils@@SAPAV1@PAVCLog@@@Z @ 36 NONAME ; public: static class CTestUtils * __cdecl CTestUtils::NewL(class CLog *)
	?OpenLogFileL@CLog@@QAEXABV?$TBuf@$0BAA@@@@Z @ 37 NONAME ; public: void __thiscall CLog::OpenLogFileL(class TBuf<256> const &)
	?RunUtils@CTestUtils@@QAEXABVTDesC16@@@Z @ 38 NONAME ; public: void __thiscall CTestUtils::RunUtils(class TDesC16 const &)
	?SetLogSystem@CTestSuite@@QAEXPAVCLog@@@Z @ 39 NONAME ; public: void __thiscall CTestSuite::SetLogSystem(class CLog *)
	?SetPutSrcInfo@CLog@@QAEXH@Z @ 40 NONAME ; public: void __thiscall CLog::SetPutSrcInfo(int)
	?SetSeverity@CLog@@QAEXH@Z @ 41 NONAME ; public: void __thiscall CLog::SetSeverity(int)
	?SetSeverity@CTestSuite@@QAEXH@Z @ 42 NONAME ; public: void __thiscall CTestSuite::SetSeverity(int)
	?Severity@CLog@@QAEHXZ @ 43 NONAME ; public: int __thiscall CLog::Severity(void)
	?Severity@CTestSuite@@QAEHXZ @ 44 NONAME ; public: int __thiscall CTestSuite::Severity(void)
	?TestCheckPointCompareL@CTestStep@@IAEXHHABVTDesC16@@PADH@Z @ 45 NONAME ; protected: void __thiscall CTestStep::TestCheckPointCompareL(int,int,class TDesC16 const &,char *,int)
	?TestResultText@CLog@@QAEPBGW4TVerdict@@@Z @ 46 NONAME ; public: unsigned short const * __thiscall CLog::TestResultText(enum TVerdict)
	?UnLoadConfig@CTestStep@@QAEXXZ @ 47 NONAME ; public: void __thiscall CTestStep::UnLoadConfig(void)
	?WriteFormat@CFileLogger@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 48 NONAME ; public: void __cdecl CFileLogger::WriteFormat(class TRefByValue<class TDesC16 const >,...)
	?doTestStepPostambleL@CTestStep@@UAE?AW4TVerdict@@XZ @ 49 NONAME ; public: virtual enum TVerdict  __thiscall CTestStep::doTestStepPostambleL(void)
	?doTestStepPreambleL@CTestStep@@UAE?AW4TVerdict@@XZ @ 50 NONAME ; public: virtual enum TVerdict  __thiscall CTestStep::doTestStepPreambleL(void)
	?testBooleanTrue@CTestStep@@IAEXHPADH@Z @ 51 NONAME ; protected: void __thiscall CTestStep::testBooleanTrue(int,char *,int)
	?testBooleanTrueL@CTestStep@@IAEXHPADH@Z @ 52 NONAME ; protected: void __thiscall CTestStep::testBooleanTrueL(int,char *,int)
	?testBooleanTrueL@CTestSuite@@IAEXHPADH@Z @ 53 NONAME ; protected: void __thiscall CTestSuite::testBooleanTrueL(int,char *,int)
	?testBooleanTrueWithErrorCode@CTestStep@@IAEXHHPADH@Z @ 54 NONAME ; protected: void __thiscall CTestStep::testBooleanTrueWithErrorCode(int,int,char *,int)
	?testBooleanTrueWithErrorCodeL@CTestStep@@IAEXHHPADH@Z @ 55 NONAME ; protected: void __thiscall CTestStep::testBooleanTrueWithErrorCodeL(int,int,char *,int)
	?OverrideSuiteName@CTestSuite@@QAEXABVTDesC16@@@Z @ 56 NONAME ; public: void __thiscall CTestSuite::OverrideSuiteName(class TDesC16 const &)
	??0CTestActiveStep@@QAE@ABVTDesC16@@@Z @ 57 NONAME ; public: __thiscall CTestActiveStep::CTestActiveStep(class TDesC16 const &)
	??0CTestActiveStep@@QAE@XZ @ 58 NONAME ; public: __thiscall CTestActiveStep::CTestActiveStep(void)
	??1CTestActiveStep@@UAE@XZ @ 59 NONAME ; public: virtual __thiscall CTestActiveStep::~CTestActiveStep(void)
	?ReStart@CActiveControl@@QAEXXZ @ 60 NONAME ; public: void __thiscall CActiveControl::ReStart(void)
	?doTestStepPostambleL@CTestActiveStep@@UAE?AW4TVerdict@@XZ @ 61 NONAME ; public: virtual enum TVerdict  __thiscall CTestActiveStep::doTestStepPostambleL(void)
	?doTestStepPreambleL@CTestActiveStep@@UAE?AW4TVerdict@@XZ @ 62 NONAME ; public: virtual enum TVerdict  __thiscall CTestActiveStep::doTestStepPreambleL(void)

